#include <gtk/gtk.h>
#include <glade/glade.h>

void
on_buffer_changed (GtkTextBuffer *buffer, gpointer user_data)
{
	gtk_text_buffer_set_modified (buffer, TRUE);
}

void
on_open_select_file (gpointer user_data, GtkWidget *widget)
{
	const gchar *filename;
	GtkTextView *textview;
	GtkTextBuffer *buffer;
	gchar *contents;
	gsize size;
	GError *error = NULL;
	GtkWidget *dialog;
	
	g_assert (GTK_IS_FILE_SELECTION (user_data));

	filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION
					     (user_data));

	textview = g_object_get_data (user_data, "textview");
	buffer = gtk_text_view_get_buffer (textview);

	gtk_text_buffer_set_text (buffer, filename, -1);

	if (g_file_get_contents (filename, &contents, &size, &error)) {
		gtk_text_buffer_set_text (buffer, contents, -1);
	} else {
		if (error) {
			dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
					GTK_MESSAGE_ERROR,
					GTK_BUTTONS_CLOSE,
					"%s", error->message);
			
			gtk_dialog_run (GTK_DIALOG (dialog));
			gtk_widget_destroy (dialog);

			g_error_free (error);
		}
	}

	gtk_widget_destroy (user_data);
}

void
on_button_open_clicked (gpointer user_data, GtkWidget *widget)
{
	GladeXML *xml;
	GtkWidget *window;

	g_assert (GTK_IS_TEXT_VIEW (user_data));

	xml = glade_xml_new ("open.glade", NULL, NULL);
	glade_xml_signal_autoconnect (xml);

	window = glade_xml_get_widget (xml, "open_window");

	g_object_set_data (G_OBJECT (window), "textview", user_data);

	gtk_widget_show (window);

	g_object_unref (xml);	
}

void
on_button_save_clicked (gpointer user_data, GtkWidget *widget)
{
	GtkTextBuffer *buffer;
	
	g_assert (GTK_IS_TEXT_VIEW (user_data));

	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (user_data));

	if (gtk_text_buffer_get_modified (buffer)) {
		g_print ("Save\n");
		gtk_text_buffer_set_modified (buffer, FALSE);
	}
}
